@@ -31,43 +31,63 @@ service_info_map = {
         IMAGEX_HOST_CN,
         {'Accept': 'application/json'},
         Credentials('', '', IMAGEX_SERVICE_NAME, REGION_CN_NORTH1),
-        5, 5, "https"),
+        10, 10, "https"),
     REGION_AP_SINGAPORE1: ServiceInfo(
         IMAGEX_HOST_SG,
         {'Accept': 'application/json'},
         Credentials('', '', IMAGEX_SERVICE_NAME, REGION_AP_SINGAPORE1),
-        5, 5, "https"),
+        10, 10, "https"),
     REGION_US_EAST1: ServiceInfo(
         IMAGEX_HOST_VA,
         {'Accept': 'application/json'},
         Credentials('', '', IMAGEX_SERVICE_NAME, REGION_US_EAST1),
-        5, 5, "https"),
+        10, 10, "https"),
     INNER_REGION_CN_NORTH1: ServiceInfo(
         IMAGEX_INNER_HOST_CN,
         {'Accept': 'application/json'},
         Credentials('', '', IMAGEX_SERVICE_NAME, REGION_CN_NORTH1),
-        5, 5),
+        10, 10),
     INNER_REGION_AP_SINGAPORE1: ServiceInfo(
         IMAGEX_INNER_HOST_SG,
         {'Accept': 'application/json'},
         Credentials('', '', IMAGEX_SERVICE_NAME, REGION_AP_SINGAPORE1),
-        5, 5),
+        10, 10),
     INNER_REGION_US_EAST1: ServiceInfo(
         IMAGEX_INNER_HOST_VA,
         {'Accept': 'application/json'},
         Credentials('', '', IMAGEX_SERVICE_NAME, REGION_US_EAST1),
-        5, 5),
+        10, 10),
 }
 
 api_info = {
+    # 模板管理
+    "CreateImageTemplate":
+        ApiInfo("POST", "/", {"Action": "CreateImageTemplate", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "DeleteImageTemplate":
+        ApiInfo("POST", "/", {"Action": "DeleteImageTemplate", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "PreviewImageTemplate":
+        ApiInfo("POST", "/", {"Action": "PreviewImageTemplate", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetImageTemplate":
+        ApiInfo("GET", "/", {"Action": "GetImageTemplate", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetAllImageTemplates":
+        ApiInfo("GET", "/", {"Action": "GetAllImageTemplates", "Version": IMAGEX_API_VERSION}, {}, {}),
+    # 资源管理相关
     "ApplyImageUpload":
         ApiInfo("GET", "/", {"Action": "ApplyImageUpload", "Version": IMAGEX_API_VERSION}, {}, {}),
     "CommitImageUpload":
         ApiInfo("POST", "/", {"Action": "CommitImageUpload", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "DeleteImageUploadFiles":
+        ApiInfo("POST", "/", {"Action": "DeleteImageUploadFiles", "Version": IMAGEX_API_VERSION}, {}, {}),
     "UpdateImageUploadFiles":
         ApiInfo("POST", "/", {"Action": "UpdateImageUploadFiles", "Version": IMAGEX_API_VERSION}, {}, {}),
     "PreviewImageUploadFile":
-        ApiInfo("GET", "/", {"Action": "PreviewImageUploadFile", "Version": IMAGEX_API_VERSION}, {}, {})
+        ApiInfo("GET", "/", {"Action": "PreviewImageUploadFile", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetImageUploadFile":
+        ApiInfo("GET", "/", {"Action": "GetImageUploadFile", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetImageUploadFiles":
+        ApiInfo("GET", "/", {"Action": "GetImageUploadFiles", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetImageUpdateFiles":
+        ApiInfo("GET", "/", {"Action": "GetImageUpdateFiles", "Version": IMAGEX_API_VERSION}, {}, {})
 }
 
 
@@ -225,3 +245,33 @@ class ImageXService(Service):
         if 'Error' in res_json['ResponseMetadata']:
             raise Exception(res_json['ResponseMetadata'])
         return res_json['Result']
+
+    def delete_images(self, service_id, uris):
+        query = {
+            'ServiceId': service_id
+        }
+        body = {
+            'StoreUris': uris
+        }
+        res = self.json('DeleteImageUploadFiles', query, json.dumps(body))
+        if res == '':
+            raise Exception("DeleteImageUploadFiles: empty response")
+        res_json = json.loads(res)
+        if 'Error' in res_json['ResponseMetadata']:
+            raise Exception(res_json['ResponseMetadata'])
+        return res_json['Result']
+
+    def imagex_get(self, action, params, doseq=0):
+        res = self.get(action, params, doseq)
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
+
+    def imagex_post(self, action, params, body):
+        res = self.json(action, params, body)
+        if res == '':
+            raise Exception("%s: empty response" % action)
+        res_json = json.loads(res)
+        return res_json
+
